"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDefaultConfig = void 0;
const fs_1 = require("fs");
const utils_1 = require("@jarvis/utils");
const defaultDevTool = utils_1.env.isDev ? 'source-map' : false;
const projectName = (_a = utils_1.getPackageJson()) === null || _a === void 0 ? void 0 : _a.name;
const getDefaultConfig = () => {
    const templatePath = fs_1.existsSync(utils_1.paths.customHtmlTemplate)
        ? utils_1.paths.customHtmlTemplate
        : utils_1.paths.defaultHtmlTemplate;
    const faviconPath = fs_1.existsSync(utils_1.paths.customFavicon)
        ? utils_1.paths.customFavicon
        : utils_1.paths.defaultFavicon;
    return {
        type: 'universal',
        server: {
            host: '0.0.0.0',
            port: 9001,
            proxy: {},
        },
        webpack: {
            alias: {
                '@': utils_1.resolveAppPath('client'),
                vue$: 'vue/dist/vue.esm.js',
            },
            entry: utils_1.paths.defaultEntry,
            outputPath: utils_1.paths.defaultOutputPath,
            publicPath: '/',
            devtool: defaultDevTool,
            sourceMap: true,
            define: {
                'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV),
                'app.stage': JSON.stringify(process.env.STAGE),
                'app.name': JSON.stringify(projectName),
            },
            babel: {
                presets: ['@babel/preset-env', '@vue/babel-preset-jsx'],
                plugins: ['@babel/plugin-proposal-class-properties'],
            },
            html: {
                template: templatePath,
                favicon: faviconPath,
            },
            less: {},
            postcss: {
                plugins: () => [require('autoprefixer')],
            },
            terser: {},
        },
        events: {},
    };
};
exports.getDefaultConfig = getDefaultConfig;
//# sourceMappingURL=default.js.map