import * as Config from 'webpack-chain';
export declare type ApplicationType = 'universal' | 'client-only' | 'server-only';
export declare type DetailedProxyConfig = {
    target: string;
    changeOrigin: boolean;
    pathRewrite: {
        [originPath: string]: string;
    };
};
export declare type CommonObject<T> = {
    [key: string]: T;
};
declare type JarvisEventNames = 'onStart' | 'onClose' | 'onError';
declare type BabelOptionItem = string | [string, Record<string, any>?];
export interface BabelOptions {
    presets?: BabelOptionItem[];
    plugins?: BabelOptionItem[];
}
interface PostCSSOptions {
    ident?: string;
    plugins?: (loader: CommonObject<any>) => any[];
}
export declare interface JarvisServerConfig {
    host: string;
    port: number;
    proxy: {
        [proxyPath: string]: string | DetailedProxyConfig;
    };
}
export declare interface JarvisWebpackConfig {
    alias: {
        [name: string]: string;
    };
    entry: string | string[];
    outputPath: string;
    publicPath: string;
    sourceMap: boolean;
    devtool: Config.DevTool;
    define: CommonObject<string>;
    babel: BabelOptions;
    html: CommonObject<string>;
    less: CommonObject<any>;
    postcss: PostCSSOptions;
    terser: CommonObject<any>;
    chain?: (config: Config, { webpack }: {
        webpack: any;
    }) => void;
}
export declare interface ProjectConfig {
    server?: Partial<JarvisServerConfig>;
    webpack?: Partial<JarvisWebpackConfig>;
    events?: {
        [eventName in JarvisEventNames]: () => void;
    };
}
export declare interface JarvisConfig {
    type: ApplicationType;
    server: JarvisServerConfig;
    webpack: JarvisWebpackConfig;
    events: {
        [eventName in JarvisEventNames]?: () => void;
    };
}
export {};
