import { paths } from './paths'
import { JarvisLogger } from '@jarvis/logger'
import { getDefaultConfig } from './default'
import * as merge from 'deepmerge'
import { env } from '@jarvis/utils'
import { requireConfigByPaths } from './requireConfigByPaths'
import { ProjectConfig, JarvisConfig, CommonObject } from './types/config'

const logger = new JarvisLogger('Config')

/**
 * 获取配置文件
 */
function getConfig(): ProjectConfig {
  const configFilePaths = env.isDev ? [
    paths.jarvisDev,
    paths.jarvis,
    paths.configDev,
    paths.config,
  ] : [
    paths.jarvisProd,
    paths.jarvis,
    paths.configProd,
    paths.config,
  ]

  return requireConfigByPaths(configFilePaths) as ProjectConfig
}

const appConfig: ProjectConfig = getConfig()

/**
 * 判断是否为对象
 * @param {object} obj 要检验的对象
 * @returns {boolean} 是否为对象
 */
function isObject(obj: CommonObject<string>): boolean {
  return Object.prototype.toString.call(obj) === '[object object]'
}

/**
 * 通过 key 值获取对象的 value
 * @param {*} data 对象
 * @param {string} target 要获取的 key 值
 * @returns {*} key 对应的返回值
 */
export function getConfigValueByKey(
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  data: CommonObject<any> = appConfig,
  target: string,
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
): CommonObject<any> | undefined {
  for (const key of Object.keys(data)) {
    if (key === 'target') {
      return data[key]
    }
    if (isObject(data[key])) {
      return getConfigValueByKey(data[key], target)
    }
  }
  logger.error(`未找到 ${target} 配置`)
  process.exit(1)
}

export const getAppConfig = (): JarvisConfig => {
  // TODO: 这里的 as JarvisConfig 是为了绕过 ts 的抛错
  // 因为 appConfig 里的属性都是 Partial 的，ts 会提示无法 assign，但实际上是可以的
  // 后面再看下有什么方法可以解决
  return merge(getDefaultConfig(), appConfig as JarvisConfig)
}
