import { existsSync } from 'fs'

import { env, paths, resolveAppPath, getPackageJson } from '@jarvis/utils'
import { JarvisConfig } from './types/config'

// 仅开发模式下默认打开 source map
const defaultDevTool = env.isDev ? 'source-map' : false

// 默认应用名称，从 package.json 取
const projectName = getPackageJson()?.name

/**
 * 获取默认配置
 */
export const getDefaultConfig = (): JarvisConfig => {
  // 根据是否配置自定义的 html 模版和 favicon 判断是否需要使用默认的模版
  const templatePath = existsSync(paths.customHtmlTemplate)
    ? paths.customHtmlTemplate
    : paths.defaultHtmlTemplate
  const faviconPath = existsSync(paths.customFavicon)
    ? paths.customFavicon
    : paths.defaultFavicon

  return {
    type: 'universal',
    server: {
      host: '0.0.0.0',
      port: 9001,
      proxy: {},
    },
    webpack: {
      alias: {
        '@': resolveAppPath('client'),
        vue$: 'vue/dist/vue.esm.js',
      },
      entry: paths.defaultEntry,
      outputPath: paths.defaultOutputPath,
      publicPath: '/',
      devtool: defaultDevTool,
      sourceMap: true,
      define: {
        'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV),
        // 透传应用阶段字段，需要在构建时注入
        'app.stage': JSON.stringify(process.env.STAGE),
        // 透传应用名称，对应 package.json 中的 name 字段
        'app.name': JSON.stringify(projectName),
      },
      babel: {
        presets: ['@babel/preset-env', '@vue/babel-preset-jsx'],
        plugins: ['@babel/plugin-proposal-class-properties'],
      },
      html: {
        template: templatePath,
        favicon: faviconPath,
      },
      less: {},
      postcss: {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        plugins: (): any[] => [require('autoprefixer')],
      },
      terser: {},
    },
    events: {},
  }
}
