/**
 * @file 从 path 队列中加载配置文件
 */
import { existsSync } from 'fs'
import { JarvisLogger } from '@jarvis/logger'
import { CommonObject } from './types/config'

const logger = new JarvisLogger('RequireConfigByPath')

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export const requireConfigByPaths = (filePaths: string[]): CommonObject<any> => {
  let readPath: string | null = null

  filePaths.some(filePath => {
    // 只要有文件存在，就读取这个文件，如果读取出错，就直接抛出
    const isExist = existsSync(filePath)

    readPath = filePath

    return isExist
  })

  if (!readPath) {
    // TODO: 优化错误提示信息
    logger.error('未找到配置文件！请确认已正确配置')

    process.exit(1)
  }

  logger.log(`正在加载 Jarvis 配置文件 ${readPath} ...`)

  return require(readPath)
}
