import * as Config from 'webpack-chain'

// 应用类型
export type ApplicationType = 'universal' | 'client-only' | 'server-only'

// 详细的代理配置
export declare type DetailedProxyConfig = {
  target: string
  changeOrigin: boolean
  pathRewrite: {
    [originPath: string]: string
  }
}

export type CommonObject<T> = {
  [key: string]: T
}

type JarvisEventNames = 'onStart' | 'onClose' | 'onError'

// eslint-disable-next-line @typescript-eslint/no-explicit-any
type BabelOptionItem = string | [string, Record<string, any>?]

// babel 配置
export interface BabelOptions {
  presets?: BabelOptionItem[]
  plugins?: BabelOptionItem[]
}

interface PostCSSOptions {
  ident?: string
  // eslint-disable-next-line
  plugins?: (loader: CommonObject<any>) => any[]
}

/**
 * 服务端配置
 */
export declare interface JarvisServerConfig {
  host: string
  port: number
  proxy: {
    [proxyPath: string]: string | DetailedProxyConfig
  },
}

/**
 * webpack 配置
 */
export declare interface JarvisWebpackConfig {
  alias: {
    [name: string]: string
  },
  entry: string | string[]
  outputPath: string
  publicPath: string
  sourceMap: boolean
  devtool: Config.DevTool
  define: CommonObject<string>
  babel: BabelOptions
  html: CommonObject<string>
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  less: CommonObject<any>
  postcss: PostCSSOptions
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  terser: CommonObject<any>
  // eslint-disable-next-line no-unused-vars
  chain?: (config: Config, { webpack }) => void
}

/**
 * 项目配置
 */
export declare interface ProjectConfig {
  server?: Partial<JarvisServerConfig>
  webpack?: Partial<JarvisWebpackConfig>
  events?: {
    // eslint-disable-next-line no-unused-vars
    [eventName in JarvisEventNames]: () => void
  }
}

/**
 * @jarvis/config 暴露出来的完整配置对象
 */
export declare interface JarvisConfig {
  type: ApplicationType
  server: JarvisServerConfig
  webpack: JarvisWebpackConfig
  events: {
    // eslint-disable-next-line no-unused-vars
    [eventName in JarvisEventNames]?: () => void
  }
}
